import openpyxl
from Homework_files.APITesting_LZJ.common.read_ini import ReadIni
from Homework_files.APITesting_LZJ.common.read_json import read_json
from Homework_files.APITesting_LZJ import log_decorator

class ReadExcel:
    def __init__(self):
        self.ini = ReadIni()
        case_data_path = self.ini.get_file_path("case")
        expect_data_path = self.ini.get_file_path("expect")
        sql_data_path = self.ini.get_file_path("sql")
        excel_path = self.ini.get_file_path("excel")
        self.case_data_dict = read_json(case_data_path)
        self.expect_data_dict = read_json(expect_data_path)
        self.sql_data_dict = read_json(sql_data_path)
        table_name = self.ini.get_table_name("table")
        try:
            wb = openpyxl.load_workbook(excel_path)
            self.ws = wb[table_name]
        except Exception as e:
            print("加载工作簿和获取工作表时报错，错误为：", e)
            raise e

    @log_decorator
    def __get_cell_value(self, column: str, row: int) -> str:
        try:
            cell_value = self.ws[column + str(row)].value
        except Exception as e:
            print("获取指定单元格数据报错，错误为：", e)
            raise e
        else:
            if cell_value is None:
                return None
            elif cell_value.strip():
                return cell_value.strip()

    @log_decorator
    def module_name(self, row):
        return self.__get_cell_value("B", row)

    @log_decorator
    def api_name(self, row):
        return self.__get_cell_value("C", row)

    @log_decorator
    def req_method(self, row):
        return self.__get_cell_value("F", row)

    @log_decorator
    def req_url(self, row):
        host = self.ini.get_url("test_host")
        path = self.__get_cell_value("G", row)
        if path is not None:
            return host+path
        else:
            return None

    @log_decorator
    def case_mime(self, row):
        mime = self.__get_cell_value("H", row)
        if mime is not None:
            return mime.lower()
        else:
            return None

    @log_decorator
    def case_data(self, row):
        case_data_key = self.__get_cell_value("i", row)
        if case_data_key is not None:
            module_name = self.module_name(row)
            api_name = self.api_name(row)
            return self.case_data_dict[module_name][api_name][case_data_key]
        else:
            return None

    @log_decorator
    def expect_data(self, row):
        expect_data_key = self.__get_cell_value("j", row)
        if expect_data_key is not None:
            module_name = self.module_name(row)
            api_name = self.api_name(row)
            return self.expect_data_dict[module_name][api_name][expect_data_key]
        else:
            return None

    @log_decorator
    def sql_type(self, row):
        sql_sentence_type = self.__get_cell_value("k", row)
        if sql_sentence_type is not None:
            return sql_sentence_type.lower()
        else:
            return None

    @log_decorator
    def sql_data(self, row):
        sql_data_key = self.__get_cell_value("l", row)
        if sql_data_key is not None:
            module_name = self.module_name(row)
            api_name = self.api_name(row)
            return self.sql_data_dict[module_name][api_name][sql_data_key]
        else:
            return None

    @log_decorator
    def update_key(self, row):
        return self.__get_cell_value("m", row)

    @log_decorator
    def get_data(self):
        data_list = []
        for row in range(2, self.ws.max_row+1):
            req_method = self.req_method(row)
            req_url = self.req_url(row)
            case_mime = self.case_mime(row)
            case_data = self.case_data(row)
            expect_data = self.expect_data(row)
            sql_type = self.sql_type(row)
            sql_data = self.sql_data(row)
            update_key = self.update_key(row)
            if req_method is not None and req_url is not None:
                row_list = [req_method, req_url, case_mime, case_data, expect_data, sql_type, sql_data, update_key]
                data_list.append(row_list)
        else:
            return data_list

if __name__ == '__main__':
    excel = ReadExcel()
    print(excel.get_data())